@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2006-2024 Univention GmbH
+# Copyright 2006-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -182,7 +182,7 @@ class ModuleServer:
             except Exception as exc:
                 error = _('Failed to load module %(module)s: %(error)s\n%(traceback)s') % {'module': modname, 'error': exc, 'traceback': traceback.format_exc()}
                 # TODO: systemctl reload univention-management-console-server
-                MODULE.error(error)
+                MODULE.error('%s', error)
                 if isinstance(exc, ImportError) and str(exc).startswith('No module named %s' % (modname,)):
                     error = '\n'.join((
                         _('The requested module %r does not exist.') % (modname,),
